Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CIDRBlock ¶
type CIDRBlock struct {
ID int
ServiceID int
ServiceName string
CIDR netip.Prefix
Ports []int
CreationDate civil.Date
EffectiveDate civil.Date
ChangeDate civil.Date
MinIP netip.Addr
MaxIP netip.Addr
LastAction LastAction
}
CIDRBlock represents a CIDR block that is allowed to access an Akamai service under the Firewall Rules Notification API.
type Client ¶
type Client struct {
Credentials akamai.Credentials
}
A Client allows access to the Akamai Firewall Rules Notification API.
func (*Client) GetCIDRBlocks ¶
GetCIDRBlocks returns all CIDR blocks for all services the client is subscribed to.
func (*Client) GetCIDRBlocksWithContext ¶ added in v0.1.2
GetCIDRBlocksWithContext returns all CIDR blocks for all services the client is subscribed to.
The context is used to determine whether debugging is enabled and to allow cancellation of the request.
func (*Client) GetService ¶
GetService returns information about a service by ID.
This is a compatibility wrapper around GetServiceWithContext that uses context.Background() as the context.
func (*Client) GetServiceWithContext ¶ added in v0.1.2
GetServiceWithContext returns information about a service by ID.
The context is used to determine whether debugging is enabled and to allow cancellation of the request.
type LastAction ¶
type LastAction string
const ( LastActionOther LastAction = "other" LastActionAdd LastAction = "add" LastActionUpdate LastAction = "update" LastActionDelete LastAction = "delete" )